@@ -50,7 +50,7 @@ def part(connection, chan, reason=None):
 
 @manager.command
 def quit(connection, reason=None):
-    connection.quiting = True
+    connection.quitting = True
     if reason:
         connection.sendl(QUIT, reason)
     else:
